@@ -49,6 +49,7 @@ class fMMS_controller():
 		self._pushdir = self.config.get_pushdir()
 		self._outdir = self.config.get_outdir()
 		self.store = DBHandler.DatabaseHandler(self)
+		self.ui = False
 	
 	def clean_url(self, url):
 		m = re.search(r"http\:\/\/(?i)", url)
@@ -105,7 +106,11 @@ class fMMS_controller():
 		return mtime
 	
 	def send_mms(self, to, subject, message, attachment, sender):
-		sender = MMSSender(to, subject, message, attachment, sender, setupConn=True)
+		try:
+			sender = MMSSender(to, subject, message, attachment, sender, setupConn=True, controller=self)
+		except:
+			msg = "%s" % (gettext.ldgettext('hildon-common-strings', "sfil_ni_operation_failed"))
+			return (-1, msg)
 		try:
 			(status, reason, output, parsed) = sender.sendMMS()
 
@@ -276,7 +281,7 @@ class fMMS_controller():
 		
 		from wappushhandler import PushHandler
 		p = PushHandler()
-		path = p._get_mms_message(url, trans_id)
+		path = p._get_mms_message(url, trans_id, self)
 		log.info("decoding mms... %s", trans_id)
 		message = self.decode_binary_mms(path)
 		log.info("storing mms...%s", trans_id)
